Class: Prism::ImplicitNode
- Inherits:
-
PrismNode
- Object
- PrismNode
- Prism::ImplicitNode
- Defined in:
- lib/prism/node.rb,
ext/prism/api_node.c
Overview
Represents a node that is implicitly being added to the tree but doesn't correspond directly to a node in the source.
{ foo: }
^^^^
{ Foo: }
^^^^
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
attr_reader value: Node.
Instance Method Summary collapse
-
#accept(visitor) ⇒ Object
def accept: (visitor: Visitor) -> void.
-
#child_nodes ⇒ Object
(also: #deconstruct)
def child_nodes: () -> Array[nil | Node].
-
#comment_targets ⇒ Object
def comment_targets: () -> Array[Node | Location].
-
#compact_child_nodes ⇒ Object
def compact_child_nodes: () -> Array.
-
#copy(**params) ⇒ Object
def copy: (**params) -> ImplicitNode.
-
#deconstruct_keys(keys) ⇒ Object
def deconstruct_keys: (keys: Array) -> Hash[Symbol, nil | Node | Array[Node] | String | Token | Array[Token] | Location].
-
#initialize(value, location) ⇒ ImplicitNode
constructor
def initialize: (value: Node, location: Location) -> void.
- #inspect(inspector = NodeInspector.new) ⇒ Object
-
#type ⇒ Object
Sometimes you want to check an instance of a node against a list of classes to see what kind of behavior to perform.
Constructor Details
#initialize(value, location) ⇒ ImplicitNode
def initialize: (value: Node, location: Location) -> void
6970 6971 6972 6973 |
# File 'lib/prism/node.rb', line 6970 def initialize(value, location) @value = value @location = location end |
Instance Attribute Details
#value ⇒ Object (readonly)
attr_reader value: Node
6967 6968 6969 |
# File 'lib/prism/node.rb', line 6967 def value @value end |
Instance Method Details
#accept(visitor) ⇒ Object
def accept: (visitor: Visitor) -> void
6976 6977 6978 |
# File 'lib/prism/node.rb', line 6976 def accept(visitor) visitor.visit_implicit_node(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
def child_nodes: () -> Array[nil | Node]
6981 6982 6983 |
# File 'lib/prism/node.rb', line 6981 def child_nodes [value] end |
#comment_targets ⇒ Object
def comment_targets: () -> Array[Node | Location]
6991 6992 6993 |
# File 'lib/prism/node.rb', line 6991 def comment_targets [value] end |
#compact_child_nodes ⇒ Object
def compact_child_nodes: () -> Array
6986 6987 6988 |
# File 'lib/prism/node.rb', line 6986 def compact_child_nodes [value] end |
#copy(**params) ⇒ Object
def copy: (**params) -> ImplicitNode
6996 6997 6998 6999 7000 7001 |
# File 'lib/prism/node.rb', line 6996 def copy(**params) ImplicitNode.new( params.fetch(:value) { value }, params.fetch(:location) { location }, ) end |
#deconstruct_keys(keys) ⇒ Object
def deconstruct_keys: (keys: Array) -> Hash[Symbol, nil | Node | Array[Node] | String | Token | Array[Token] | Location]
7007 7008 7009 |
# File 'lib/prism/node.rb', line 7007 def deconstruct_keys(keys) { value: value, location: location } end |
#inspect(inspector = NodeInspector.new) ⇒ Object
7011 7012 7013 7014 7015 7016 |
# File 'lib/prism/node.rb', line 7011 def inspect(inspector = NodeInspector.new) inspector << inspector.header(self) inspector << "└── value:\n" inspector << inspector.child_node(value, " ") inspector.to_str end |
#type ⇒ Object
Sometimes you want to check an instance of a node against a list of
classes to see what kind of behavior to perform. Usually this is done by
calling [cls1, cls2].include?(node.class) or putting the node into a
case statement and doing case node; when cls1; when cls2; end. Both of
these approaches are relatively slow because of the constant lookups,
method calls, and/or array allocations.
Instead, you can call #type, which will return to you a symbol that you can use for comparison. This is faster than the other approaches because it uses a single integer comparison, but also because if you're on CRuby you can take advantage of the fact that case statements with all symbol keys will use a jump table.
def type: () -> Symbol
7032 7033 7034 |
# File 'lib/prism/node.rb', line 7032 def type :implicit_node end |