Class: Prism::RetryNode

Inherits:
PrismNode
  • Object
show all
Defined in:
lib/prism/node.rb,
ext/prism/api_node.c

Overview

Represents the use of the retry keyword.

retry
^^^^^

Instance Method Summary collapse

Constructor Details

#initialize(location) ⇒ RetryNode

def initialize: (location: Location) -> void



12419
12420
12421
# File 'lib/prism/node.rb', line 12419

def initialize(location)
  @location = location
end

Instance Method Details

#accept(visitor) ⇒ Object

def accept: (visitor: Visitor) -> void



12424
12425
12426
# File 'lib/prism/node.rb', line 12424

def accept(visitor)
  visitor.visit_retry_node(self)
end

#child_nodesObject Also known as: deconstruct

def child_nodes: () -> Array[nil | Node]



12429
12430
12431
# File 'lib/prism/node.rb', line 12429

def child_nodes
  []
end

#comment_targetsObject

def comment_targets: () -> Array[Node | Location]



12439
12440
12441
# File 'lib/prism/node.rb', line 12439

def comment_targets
  []
end

#compact_child_nodesObject

def compact_child_nodes: () -> Array



12434
12435
12436
# File 'lib/prism/node.rb', line 12434

def compact_child_nodes
  []
end

#copy(**params) ⇒ Object

def copy: (**params) -> RetryNode



12444
12445
12446
12447
12448
# File 'lib/prism/node.rb', line 12444

def copy(**params)
  RetryNode.new(
    params.fetch(:location) { location },
  )
end

#deconstruct_keys(keys) ⇒ Object

def deconstruct_keys: (keys: Array) -> Hash[Symbol, nil | Node | Array[Node] | String | Token | Array[Token] | Location]



12454
12455
12456
# File 'lib/prism/node.rb', line 12454

def deconstruct_keys(keys)
  { location: location }
end

#inspect(inspector = NodeInspector.new) ⇒ Object



12458
12459
12460
12461
# File 'lib/prism/node.rb', line 12458

def inspect(inspector = NodeInspector.new)
  inspector << inspector.header(self)
  inspector.to_str
end

#typeObject

Sometimes you want to check an instance of a node against a list of classes to see what kind of behavior to perform. Usually this is done by calling [cls1, cls2].include?(node.class) or putting the node into a case statement and doing case node; when cls1; when cls2; end. Both of these approaches are relatively slow because of the constant lookups, method calls, and/or array allocations.

Instead, you can call #type, which will return to you a symbol that you can use for comparison. This is faster than the other approaches because it uses a single integer comparison, but also because if you're on CRuby you can take advantage of the fact that case statements with all symbol keys will use a jump table.

def type: () -> Symbol



12477
12478
12479
# File 'lib/prism/node.rb', line 12477

def type
  :retry_node
end